@@ -13,7 +13,7 @@ gyr = Volume(U).isosurface(0).smooth().subdivide()
 sph = Sphere(pos=(15,15,15), r=14, quads=True, res=30).triangulate()
 printc("Please wait a few secs while I'm cutting your gyroid", c='y')
 gxs = gyr.boolean('intersect', sph).clean().flat()
-gxs.texture('https://www.dropbox.com/s/d99h7sh7rx7drah/marblings.jpg')
+gxs.texture('https://vedo.embl.es/examples/data/images/marblings.jpg')
 
 plt = show(gxs, __doc__, bg='wheat', bg2='lightblue', axes=5, zoom=1.4)
 # Video('gyroid.mp4').action().close().interactive() # shoot video
