@@ -9,7 +9,7 @@ for name in colors.cmaps_names:
     cols = colorMap(range(n), name)
 
     # make a strip of n cells and assing them individual colors
-    gr = Grid(sx=50, resx=n, sy=1, resy=1).cellIndividualColors(cols)
+    gr = Grid(sx=50, resx=n, sy=1, resy=1).cellIndividualColors(cols*255)
     gr.lineWidth(0).wireframe(False).y(-i*1.2)
     grids.append([gr, gr.box().c('grey')])
 
@@ -20,7 +20,10 @@ for name in colors.cmaps_names:
     vnames2.append(tx2)
     i += 1
 
-printc("Try picking a color by pressing Shift-i", invert=1)
-show(grids, vnames1, at=0, N=2, size=(1300,1000), bg='blackboard',
+printc("Try picking a color by pressing Shift-i", invert=True)
+
+show(grids, vnames1,
+     at=0, N=2, size=(1300,1000), bg='blackboard',
      title="Color Maps with n="+str(n)+" colors")
-show(grids, vnames2, at=1, bg='white', zoom=1.75, interactive=True).close()
+show(grids, vnames2,
+     at=1, bg='white', zoom=1.75, interactive=True, mode='image').close()
