@@ -1,8 +1,10 @@
 """Draw the ellipsoid that contains 50% of a cloud of Points,
 then check how many points are inside the surface"""
-from vedo import pcaEllipsoid, show
+from vedo import settings, pcaEllipsoid, show
 import numpy as np
 
+settings.useDepthPeeling = True
+
 pts = np.random.randn(10000, 3)/1.5*[3,2,1]  # random gaussian point cloud
 
 elli = pcaEllipsoid(pts, pvalue=0.5)
@@ -19,4 +21,4 @@ print("inside  points #", inpcl.NPoints() )
 print("outside points #", outpcl.NPoints() )
 print("asphericity:", elli.asphericity(), '+-', elli.asphericity_error())
 
-show(elli, inpcl, outpcl, __doc__, axes=1)
+show(elli, inpcl, outpcl, __doc__, axes=1).close()
