@@ -131,10 +131,8 @@ class Base3DProp(object):
         self.trailPoints = []
         self.trailSegmentSize = 0
         self.trailOffset = None
-        self.shadow = None
-        self.shadowX = None
-        self.shadowY = None
-        self.shadowZ = None
+        self.shadows = []
+        self.shadowsArgs = []
         self.axes = None
         self.picked3d = None
         self.units = None
@@ -210,7 +208,7 @@ class Base3DProp(object):
 
         if self.trail:
             self.updateTrail()
-        if self.shadow:
+        if len(self.shadows) > 0:
             self._updateShadow()
         return self  # return itself to concatenate methods
 
@@ -228,7 +226,7 @@ class Base3DProp(object):
 
         if self.trail:
             self.updateTrail()
-        if self.shadow:
+        if len(self.shadows) > 0:
             self._updateShadow()
         return self
 
@@ -244,7 +242,7 @@ class Base3DProp(object):
         self.SetPosition(position, p[1], p[2])
         if self.trail:
             self.updateTrail()
-        if self.shadow:
+        if len(self.shadows) > 0:
             self._updateShadow()
         return self
 
@@ -256,7 +254,7 @@ class Base3DProp(object):
         self.SetPosition(p[0], position, p[2])
         if self.trail:
             self.updateTrail()
-        if self.shadow:
+        if len(self.shadows) > 0:
             self._updateShadow()
         return self
 
@@ -268,7 +266,7 @@ class Base3DProp(object):
         self.SetPosition(p[0], p[1], position)
         if self.trail:
             self.updateTrail()
-        if self.shadow:
+        if len(self.shadows) > 0:
             self._updateShadow()
         return self
 
@@ -312,10 +310,8 @@ class Base3DProp(object):
         self.SetPosition(rv)
         if self.trail:
             self.updateTrail()
-        if self.shadow:
-            self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                           self.shadow.GetProperty().GetColor(),
-                           self.shadow.GetProperty().GetOpacity())
+        if len(self.shadows) > 0:
+            self.addShadows()
         return self
 
     def rotateX(self, angle, rad=False, locally=False):
@@ -335,10 +331,8 @@ class Base3DProp(object):
             self.SetPosition(T.GetPosition())
             if self.trail:
                 self.updateTrail()
-            if self.shadow:
-                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                               self.shadow.GetProperty().GetColor(),
-                               self.shadow.GetProperty().GetOpacity())
+            if len(self.shadows) > 0:
+                self.addShadows()
         else:
             self.RotateX(angle)
         return self
@@ -360,10 +354,8 @@ class Base3DProp(object):
             self.SetPosition(T.GetPosition())
             if self.trail:
                 self.updateTrail()
-            if self.shadow:
-                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                               self.shadow.GetProperty().GetColor(),
-                               self.shadow.GetProperty().GetOpacity())
+            if len(self.shadows) > 0:
+                self.addShadows()
         else:
             self.RotateY(angle)
         return self
@@ -385,10 +377,8 @@ class Base3DProp(object):
             self.SetPosition(T.GetPosition())
             if self.trail:
                 self.updateTrail()
-            if self.shadow:
-                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                               self.shadow.GetProperty().GetColor(),
-                               self.shadow.GetProperty().GetOpacity())
+            if len(self.shadows) > 0:
+                self.addShadows()
         else:
             self.RotateZ(angle)
         return self
@@ -438,13 +428,10 @@ class Base3DProp(object):
         self.SetUserTransform(T)
         if self.trail:
             self.updateTrail()
-        if self.shadow:
-            self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                           self.shadow.GetProperty().GetColor(),
-                           self.shadow.GetProperty().GetOpacity())
+        if len(self.shadows) > 0:
+            self.addShadows()
         return self
 
-
     def scale(self, s=None, absolute=False):
         """Set/get object's scaling factor.
 
@@ -715,6 +702,16 @@ class Base3DProp(object):
         """
         return vedo.plotter.show(self, **options)
 
+    def addShadows(self):
+        shadows = self.shadows
+        shadowsArgs = self.shadowsArgs
+        self.shadows = []
+        self.shadowsArgs = []
+        for sha, args in zip(shadows, shadowsArgs):
+            color = sha.GetProperty().GetColor()
+            opacity = sha.GetProperty().GetOpacity()
+            self.addShadow(**args, c=color, alpha=opacity)
+
 
 ########################################################################################
 class BaseActor(Base3DProp):
@@ -1211,25 +1208,35 @@ class BaseActor(Base3DProp):
                      c=None,
                      horizontal=False,
                      useAlpha=True,
+                     tformat='%-#6.3g',
     ):
         """
         Add a 2D scalar bar for the specified obj.
 
         .. hint:: |mesh_coloring| |mesh_coloring.py|_ |scalarbars.py|_
         """
-        self.scalarbar = vedo.addons.addScalarBar(self,
-                                                  title,
-                                                  pos,
-                                                  titleYOffset,
-                                                  titleFontSize,
-                                                  size,
-                                                  nlabels,
-                                                  c,
-                                                  horizontal,
-                                                  useAlpha,
-                                                 )
-        return self
+        plt = vedo.settings.plotter_instance
 
+        if not hasattr(self, "mapper"):
+            colors.printc("Error in addScalarBar(): input is invalid,", type(self), c='r')
+            return None
+
+        if plt and plt.renderer:
+            c = (0.9, 0.9, 0.9)
+            if np.sum(plt.renderer.GetBackground()) > 1.5:
+                c = (0.1, 0.1, 0.1)
+            if isinstance(self.scalarbar, vtk.vtkActor):
+                plt.renderer.RemoveActor(self.scalarbar)
+            elif isinstance(self.scalarbar, vedo.Assembly):
+                for a in self.scalarbar.getMeshes():
+                    plt.renderer.RemoveActor(a)
+        if c is None: c = 'gray'
+
+        sb = vedo.addons.ScalarBar(self, title, pos, titleYOffset, titleFontSize,
+                                   size, nlabels, c, horizontal, useAlpha, tformat)
+
+        self.scalarbar = sb
+        return self
 
     def addScalarBar3D( self,
                         title='',
@@ -1237,14 +1244,14 @@ class BaseActor(Base3DProp):
                         sx=None,
                         sy=None,
                         titleFont="",
-                        titleXOffset = -1.5,
-                        titleYOffset = 0.0,
-                        titleSize =  1.5,
-                        titleRotation = 0.0,
+                        titleXOffset=-1.5,
+                        titleYOffset=0.0,
+                        titleSize=1.5,
+                        titleRotation= 0.0,
                         nlabels=9,
                         labelFont="",
                         labelSize=1,
-                        labelOffset = 0.375,
+                        labelOffset=0.375,
                         labelRotation=0,
                         italic=0,
                         c=None,
@@ -1256,15 +1263,8 @@ class BaseActor(Base3DProp):
                         categories=None,
         ):
         """
-        Draw a 3D scalar bar.
-
-        ``obj`` input can be:
-            - a list of numbers,
-            - a list of two numbers in the form `(min, max)`,
-            - a ``Mesh`` already containing a set of scalars associated to vertices or cells,
-            - if ``None`` the last object in the list of actors will be used.
-
-        Return an ``Assembly`` object.
+        Associate a 3D scalar bar to the object and add it to the scene.
+        The new scalarbar object (Assembly) will be accessible as obj.scalarbar
 
         :param str title: scalar bar title
         :param float sx: thickness of scalarbar
@@ -1285,35 +1285,43 @@ class BaseActor(Base3DProp):
         :param str belowText: text to show for below scale values
         :param str nanText: text to show for nan values
 
-        |mesh_coloring| |mesh_coloring.py|_
+        .. hint:: |scalarbars| |scalarbars.py|_
         """
-        self.scalarbar = vedo.addons.addScalarBar3D(self,
-                                                    title,
-                                                    pos,
-                                                    sx,
-                                                    sy,
-                                                    titleFont,
-                                                    titleXOffset,
-                                                    titleYOffset,
-                                                    titleSize,
-                                                    titleRotation,
-                                                    nlabels,
-                                                    labelFont,
-                                                    labelSize,
-                                                    labelOffset,
-                                                    labelRotation,
-                                                    italic,
-                                                    c,
-                                                    useAlpha,
-                                                    drawBox,
-                                                    aboveText,
-                                                    belowText,
-                                                    nanText,
-                                                    categories,
-                                                    )
+        plt = vedo.settings.plotter_instance
+        if plt and c is None:  # automatic black or white
+            c = (0.9, 0.9, 0.9)
+            if np.sum(vedo.getColor(plt.backgrcol)) > 1.5:
+                c = (0.1, 0.1, 0.1)
+        if c is None: c = (0,0,0)
+        c = vedo.getColor(c)
+
+        self.scalarbar = vedo.addons.ScalarBar3D(self,
+                                                title,
+                                                pos,
+                                                sx,
+                                                sy,
+                                                titleFont,
+                                                titleXOffset,
+                                                titleYOffset,
+                                                titleSize,
+                                                titleRotation,
+                                                nlabels,
+                                                labelFont,
+                                                labelSize,
+                                                labelOffset,
+                                                labelRotation,
+                                                italic,
+                                                c,
+                                                useAlpha,
+                                                drawBox,
+                                                aboveText,
+                                                belowText,
+                                                nanText,
+                                                categories,
+        )
         return self
 
-
+    ###################################################################################
     def write(self, filename, binary=True):
         """Write object to file."""
         return vedo.io.write(self, filename, binary)
@@ -1574,7 +1582,7 @@ class BaseGrid(BaseActor):
         return a
 
 
-    def legosurface(self, vmin=None, vmax=None, invert=False, cmap='afmhot_r'):
+    def legosurface(self, vmin=None, vmax=None, invert=False, cmap='afmhot_r', boundary=True):
         """
         Represent an object - typically a Volume - as lego blocks (voxels).
         By default colors correspond to the volume's scalar.
@@ -1605,7 +1613,7 @@ class BaseGrid(BaseActor):
         extract.SetInputData(self._data)
         extract.SetImplicitFunction(window)
         extract.SetExtractInside(invert)
-        extract.ExtractBoundaryCellsOff()
+        extract.SetExtractBoundaryCells(boundary)
         extract.Update()
 
         gf = vtk.vtkGeometryFilter()
