@@ -1,5 +1,4 @@
 import vtk
-from vtk.util.numpy_support import vtk_to_numpy
 import numpy as np
 import sys, os, time
 import vedo.docs as docs
@@ -658,13 +657,16 @@ def getColorName(c):
 def hsv2rgb(hsv):
     """Convert HSV to RGB color."""
     ma = vtk.vtkMath()
-    return ma.HSVToRGB(hsv)
-
+    rgb = [0,0,0]
+    ma.HSVToRGB(hsv, rgb)
+    return rgb
 
 def rgb2hsv(rgb):
     """Convert RGB to HSV color."""
     ma = vtk.vtkMath()
-    return ma.RGBToHSV(getColor(rgb))
+    hsv = [0,0,0]
+    ma.RGBToHSV(getColor(rgb), hsv)
+    return hsv
 
 def rgb2hex(rgb):
     """Convert RGB to Hex color."""
@@ -1078,25 +1080,6 @@ def printd(*strings, q=False):
     sys.stdout.flush()
 
 
-def colorPicker(xy, plotter=None):
-    """Pick color of specific (x,y) pixel on the screen."""
-    w2if = vtk.vtkWindowToImageFilter()
-    if plotter is None:
-        plotter = settings.plotter_instance
-    w2if.SetInput(plotter.window)
-    w2if.ReadFrontBufferOff()
-    w2if.Update()
-    nx, ny = plotter.window.GetSize()
-    varr = w2if.GetOutput().GetPointData().GetScalars()
-    arr = vtk_to_numpy(varr).reshape(ny,nx,3)
-    if int(xy[1])<ny and int(xy[0])<nx:
-        return arr[int(xy[1]),int(xy[0])]
-    return None
-
-
-
-
-
 
 
 
