@@ -1906,8 +1906,6 @@ class Video:
         else:
             self.fps = int(self.fps)
 
-        self.name = self.name.split('.')[0]+'.mp4'
-
         ########################################
         if self.backend == 'ffmpeg':
             out = os.system(self.command + " " + str(self.fps)
@@ -1929,6 +1927,7 @@ class Video:
             cap = cv2.VideoCapture(os.path.join(self.tmp_dir.name, "%1d.png"))
             fourcc = cv2.VideoWriter_fourcc(*"mp4v")
             w,h = settings.plotter_instance.window.GetSize()
+            w,h = w*settings.screeshotScale, h*settings.screeshotScale
             writer = cv2.VideoWriter(self.name, fourcc, self.fps, (w, h), True)
 
             found = False
