@@ -339,7 +339,6 @@ def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, te
             vertices = np.c_[vertices, np.zeros(len(vertices))]
 
     sourcePoints = vtk.vtkPoints()
-    # sourcePoints.SetData(numpy_to_vtk(np.ascontiguousarray(vertices), deep=True))
     sourcePoints.SetData(numpy2vtk(vertices, dtype=float))
     poly.SetPoints(sourcePoints)
 
@@ -1247,7 +1246,7 @@ def printInfo(obj):
 
         printc(" Click mesh and press i for info.", c="c")
 
-    elif isinstance(obj, vedo.Picture):  # dumps Plotter info
+    elif isinstance(obj, vedo.Picture):  # dumps Picture info
         printc("_" * 65, c="y", bold=0)
         printc("Picture", c="y", bold=1, invert=1)
 
@@ -1271,8 +1270,10 @@ def printInfo(obj):
         bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
         printc(" z=(" + bz1 + ", " + bz2 + ")", c="y", bold=0)
 
-        printc("     scalar range: ", c="y", bold=1, end="")
+        printc("  intensity range: ", c="y", bold=1, end="")
         printc(img.GetScalarRange(), c="y", bold=0)
+        printc("   level / window: ", c="y", bold=1, end="")
+        printc(obj.level(), '/', obj.window(), c="y", bold=0)
 
     else:
         printc(type(obj), invert=1)
@@ -1700,27 +1701,13 @@ def vedo2trimesh(mesh):
 
     from trimesh import Trimesh
 
-    lut = mesh.mapper().GetLookupTable()
-
     tris = mesh.faces()
     carr = mesh.celldata['CellIndividualColors']
-    ccols = None
-    if carr is not None and len(carr)==len(tris):
-        ccols = []
-        for i in range(len(tris)):
-            r,g,b,a = lut.GetTableValue(carr[i])
-            ccols.append((r*255, g*255, b*255, a*255))
-        ccols = np.array(ccols, dtype=np.int16)
+    ccols = carr
 
     points = mesh.points()
     varr = mesh.pointdata['VertexColors']
-    vcols = None
-    if varr is not None and len(varr)==len(points):
-        vcols = []
-        for i in range(len(points)):
-            r,g,b,a = lut.GetTableValue(varr[i])
-            vcols.append((r*255, g*255, b*255, a*255))
-        vcols = np.array(vcols, dtype=np.int16)
+    vcols = varr
 
     if len(tris)==0:
         tris = None
@@ -1728,7 +1715,7 @@ def vedo2trimesh(mesh):
     return Trimesh(vertices=points, faces=tris,
                    face_colors=ccols, vertex_colors=vcols)
 
-def trimesh2vedo(inputobj, alphaPerCell=False):
+def trimesh2vedo(inputobj):
     """
     Convert ``Trimesh`` object to ``Mesh(vtkActor)`` or ``Assembly`` object.
     """
@@ -1738,8 +1725,6 @@ def trimesh2vedo(inputobj, alphaPerCell=False):
             vms.append(trimesh2vedo(ob))
         return vms
 
-    # print('trimesh2vedo inputobj', type(inputobj))
-
     inputobj_type = str(type(inputobj))
 
     if "Trimesh" in inputobj_type or "primitives" in inputobj_type:
@@ -1756,15 +1741,12 @@ def trimesh2vedo(inputobj, alphaPerCell=False):
         if isSequence(trim_c):
             if isSequence(trim_c[0]):
                 sameColor = len(np.unique(trim_c, axis=0)) < 2 # all vtxs have same color
-                trim_c = trim_c/255
 
                 if sameColor:
                     tact.c(trim_c[0, [0,1,2]]).alpha(trim_c[0, 3])
                 else:
                     if inputobj.visual.kind == "face":
-                        tact.cellIndividualColors(trim_c[:, [0,1,2]],
-                                                  alpha=trim_c[:,3],
-                                                  alphaPerCell=alphaPerCell)
+                        tact.cellIndividualColors(trim_c)
         return tact
 
     elif "PointCloud" in inputobj_type:
